@@ -1,3 +1,4 @@
+import math
 import tkinter as tk
 from tkinter import ttk
 
@@ -48,7 +49,7 @@ class Tk:
 
     def configure_scrollbar(self, x_scroll, y_scroll):
         container = tk.Frame(self.root)
-        container.pack(fill=tk.BOTH, expand=1)
+        container.pack(fill=tk.BOTH, expand=True)
 
         canvas = tk.Canvas(container)
 
@@ -70,7 +71,7 @@ class Tk:
             x_scrollbar.pack(side=tk.BOTTOM, fill=tk.X)
             canvas.configure(xscrollcommand=x_scrollbar.set)
 
-        canvas.pack(side=tk.LEFT, fill=tk.BOTH, expand=1)
+        canvas.pack(side=tk.LEFT, fill=tk.BOTH, expand=True)
         canvas.bind(
             '<Configure>',
             lambda e: canvas.configure(scrollregion=canvas.bbox('all'))
@@ -89,8 +90,8 @@ class Tk:
     def add_component(
         self,
         component_class,
-        parent_frame=None,
         parent=None,
+        parent_frame=None,
         **kwargs
     ):
         if parent is not None:
@@ -129,6 +130,7 @@ class Component:
     ):
         self.parent = parent
         if parent_frame is not None:
+            print(self, parent_frame)
             p = parent_frame
         else:
             p = parent.tkinter
@@ -184,7 +186,11 @@ class Component:
                 sticky=self.fill['sticky']
             )
         else:
-            self.tkinter.pack(fill=self.fill['fill'], padx=self.padx, pady=self.pady)
+            self.tkinter.pack(
+                fill=self.fill['fill'],
+                padx=self.padx,
+                pady=self.pady
+            )
 
 
     def destroy(self):
@@ -200,16 +206,13 @@ class Frame(Component):
         grid_children=False,
         max_columns=None,
         update_func=None,
-        padding=['left', 'top', 'right', 'bottom'], # in int
         fill='both',
-        padx=0,
-        pady=0,
-        parent_frame=None,
+        parent_frame=None
     ):
         super().__init__(
-            parent,
-            parent_frame,
-            fill
+            parent=parent,
+            parent_frame=parent_frame,
+            fill=fill
         )
 
         self.max_columns = max_columns
@@ -221,18 +224,25 @@ class Frame(Component):
         self.update_func = update_func
         self.cur_column = 0
         self.cur_row = 0
+        self.total_rows = 0
 
 
     def add_component(
             self,
             component_class,
             parent=None,
+            fill=None,
             **kwargs
     ):
         for c in COMPONENTS:
             if issubclass(component_class, c):
                 parent = parent if parent is not None else self
-                component = component_class(parent=parent, fill=self.fill_children, **kwargs)
+                if fill is not None:
+                    f = FILL[fill]
+                else:
+                    f = self.fill
+
+                component = component_class(parent=parent, fill=f, **kwargs)
                 self.components.append(component)
                 return component
         raise ValueError(f'Invalid Component Class passed to {self} during add_component call')
@@ -259,6 +269,28 @@ class Frame(Component):
 
     def pack(self, just_children=False, grid=None):
         if self.grid_children:
+            if not self.max_columns:
+                self.total_rows = len(self.components)
+            else:
+                self.total_rows = math.ceil(len(self.components) / self.max_columns)
+
+            if (
+                self.fill['fill'] == 'both'
+                or self.fill['fill'] == 'x'
+            ):
+                if self.max_columns is not None:
+                    for i in range(self.max_columns):
+                        self.tkinter.columnconfigure(i, weight=1)
+                        print(i, self)
+                else:
+                    self.tkinter.columnconfigure(0, weight=1)
+            if (
+                self.fill['fill'] == 'both'
+                or self.fill['fill'] == 'y'
+            ):
+                for i in range(self.total_rows):
+                    self.tkinter.rowconfigure(i, weight=1)
+
             for component in self.components:
                 component.pack(
                     grid={
@@ -295,9 +327,9 @@ class Button(Component):
         parent_frame=None
     ):
         super().__init__(
-            parent,
-            parent_frame,
-            fill
+            parent=parent,
+            parent_frame=parent_frame,
+            fill=fill
         )
 
         self.tkinter = ttk.Button(
@@ -455,10 +487,10 @@ class CheckButton(Component):
     def _value_trace(self):
         self.update()
         if self._active.get():
-            if self._value.get() == self._off_value:
+            if self._value.get() != self._on_value:
                 self._value.set(self._on_value)
         else:
-            if self._value.get() == self._on_value:
+            if self._value.get() != self._off_value:
                 self._value.set(self._off_value)
         
 
@@ -534,9 +566,9 @@ class OptionMenu(Component):
         fill='both'
     ):
         super().__init__(
-            parent,
-            parent_frame,
-            fill
+            parent=parent,
+            parent_frame=parent_frame,
+            fill=fill
         )
 
         if variable:
@@ -544,7 +576,7 @@ class OptionMenu(Component):
         else:
             self._value = self.add_var('str')
 
-        self.tkinter = ttk.OptionMenu(
+        self.tkinter = tk.OptionMenu(
             self.parent_frame,
             variable=self._value,
             value=default
@@ -602,13 +634,13 @@ class RadioMenu(Frame):
         fill='both'
     ):
         super().__init__(
-            parent,
-            fill_children,
-            grid_children,
-            max_columns,
-            update_func,
-            parent_frame,
-            fill
+            parent=parent,
+            fill_children=fill_children,
+            grid_children=grid_children,
+            max_columns=max_columns,
+            update_func=update_func,
+            parent_frame=parent_frame,
+            fill=fill,
         )
 
         self.data_type = data_type
@@ -667,13 +699,13 @@ class LabeledOption(Frame):
         fill='both'
     ):
         super().__init__(
-            parent,
-            fill_children,
-            grid_children,
-            max_columns,
-            update_func,
-            parent_frame,
-            fill
+            parent=parent,
+            fill_children=fill_children,
+            grid_children=grid_children,
+            max_columns=max_columns,
+            update_func=update_func,
+            parent_frame=parent_frame,
+            fill=fill
         )
         if variable:
             self._value = variable
@@ -726,13 +758,13 @@ class LabeledEntry(Frame):
         fill='both'
     ):
         super().__init__(
-            parent,
-            fill_children,
-            grid_children,
-            max_columns,
-            update_func,
-            parent_frame,
-            fill
+            parent=parent,
+            fill_children=fill_children,
+            grid_children=grid_children,
+            max_columns=max_columns,
+            update_func=update_func,
+            parent_frame=parent_frame,
+            fill=fill
         )
         
         self.label = self.add_component(
@@ -769,13 +801,13 @@ class ButtonMatrix(Frame):
         fill='both'
     ):
         super().__init__(
-            parent,
-            fill_children,
-            grid_children,
-            max_columns,
-            update_func,
-            parent_frame,
-            fill
+            parent=parent,
+            fill_children=fill_children,
+            grid_children=grid_children,
+            max_columns=max_columns,
+            update_func=update_func,
+            parent_frame=parent_frame,
+            fill=fill
         )
 
         if isinstance(buttons, list):
@@ -783,14 +815,16 @@ class ButtonMatrix(Frame):
                 self.add_component(
                     Button,
                     text=text,
-                    command=self._pass
+                    command=self._pass,
+                    fill='both'
                 )
         else:
             for text, command in buttons.items():
                 self.add_component(
                     Button,
                     text=text,
-                    command=command
+                    command=command,
+                    fill='both'
                 )
 
 
